"""
AQI_USA 公共配置文件

"""

AQI_LEVEL = [1, 2, 3, 4, 5, 6]
POLLUTANT = [
    "PM2.5",
    "PM10",
    "SO2",
    "NO2",
    "CO",
    "O3",
]
POLLUTANT_UNITS = {
    "PM2.5": "ug/m**3",
    "PM10": "ug/m**3",
    "SO2": "ppb",
    "NO2": "ppb",
    "CO": "ppm",
    "O3": "ppb",
}
# 颗粒物24小时 0-325.4 ug/m**3
pm25_24h_minmax = (0, 325.4)
pm25_24h_breakpoints = [
    (0, 9.0, 0, 50),
    (9.1, 35.4, 51, 100),
    (35.5, 55.4, 101, 150),
    (55.5, 125.4, 151, 200),
    (125.5, 225.4, 201, 300),
    (225.5, 325.4, 301, 500),
]

# 颗粒物10小时 0-604 ug/m**3
pm10_24h_minmax = (0, 604)
pm10_24h_breakpoints = [
    (0, 54, 0, 50),
    (55, 154, 51, 100),
    (155, 254, 101, 150),
    (255, 354, 151, 200),
    (355, 424, 201, 300),
    (425, 604, 301, 500),
]

# 二氧化硫1小时 0-304 ppb
so2_1h_minmax = (0, 185)
so2_1h_breakpoints = [
    (0, 35, 0, 50),
    (36, 75, 51, 100),
    (76, 185, 101, 150),
    (186, 304, 151, 200),
]

# 二氧化硫24小时 305-1004 ppb
so2_24h_minmax = (305, 1004)
so2_24h_breakpoints = [
    (305, 604, 201, 300),
    (605, 1004, 301, 500),
]

# 二氧化氮1小时 0-1249 ppb
no2_1h_minmax = (0, 1249)
no2_1h_breakpoints = [
    (0, 53, 0, 50),
    (54, 100, 51, 100),
    (101, 360, 101, 150),
    (361, 649, 151, 200),
    (650, 1249, 201, 300),
    (1250, 2049, 301, 500),
]

# 一氧化碳8小时 0-50.4 ppm
co_8h_minmax = (0, 50.4)
co_8h_breakpoints = [
    (0, 4.4, 0, 50),
    (4.4, 9.4, 51, 100),
    (9.5, 12.4, 101, 150),
    (12.5, 15.4, 151, 200),
    (15.5, 30.4, 201, 300),
    (30.5, 50.4, 301, 500),
]


# 臭氧计算策略
# Tips 1:
# 一般情况下，各地区需要基于 8 小时臭氧（O₃） 值来报告 空气质量指数（AQI）。
# 然而，在少数情况下，基于 1 小时臭氧（O₃） 值的 AQI 可能更加谨慎。
# 对于这些情况，除了计算 8 小时臭氧指数值 之外，还可以计算 1 小时臭氧指数值，并报告两者中的最大值。
# 臭氧8小时 0.0-0.200 ppm

# Tips 2:
# 8 小时臭氧（O₃） 值不会用于确定 较高的 AQI 值（≥ 301）。
# 当 AQI 值达到 301 或以上 时，将基于 1 小时臭氧（O₃） 浓度进行计算。

# 臭氧1小时 0.125-0.404 ppm
o3_8h_minmax = (0, 0.200)
o3_8h_breakpoints = [
    (0, 0.054, 0, 50),
    (0.054, 0.070, 51, 100),
    (0.071, 0.085, 101, 150),
    (0.086, 0.105, 151, 200),
    (0.106, 0.200, 201, 300),
]

# 臭氧1小时 0.125-0.404 ppm
o3_1h_minmax = (0.125, 0.604)
o3_1h_breakpoints = [
    (0.125, 0.164, 101, 150),
    (0.165, 0.204, 151, 200),
    (0.205, 0.404, 201, 300),
    (0.405, 0.604, 301, 500),
]

# 定义断点映射
breakpoints = {
    "PM25_24H": pm25_24h_breakpoints,
    "PM10_24H": pm10_24h_breakpoints,
    "SO2_1H": so2_1h_breakpoints,
    "SO2_24H": so2_24h_breakpoints,
    "NO2_1H": no2_1h_breakpoints,
    "CO_8H": co_8h_breakpoints,
    "O3_8H": o3_8h_breakpoints,
    "O3_1H": o3_1h_breakpoints,
}
minmaxs = {
    "PM25_24H": pm25_24h_minmax,
    "PM10_24H": pm10_24h_minmax,
    "SO2_1H": so2_1h_minmax,
    "SO2_24H": so2_24h_minmax,
    "NO2_1H": no2_1h_minmax,
    "CO_8H": co_8h_minmax,
    "O3_8H": o3_8h_minmax,
    "O3_1H": o3_1h_minmax,
}

# 临界值
singularities = {
    # O3_1H 小于 0.125 无数据
    "O3_1H": 0.125,  # ppm
    # O3_8H 大于 0.201 无数据
    "O3_8H": 0.201,  # ppm
    # SO2_1H 大于 304 无数据
    "SO2_1H": 304,  # ppb
    # SO2_24H  小于 305 无数据
    "SO2_24H": 305,  # ppb
}

# 浓度值缩放因子
scales = {
    "PM25_24H": 10,
    "PM10_24H": 1,
    "SO2_1H": 1,
    "SO2_24H": 1,
    "NO2_1H": 1,
    "CO_8H": 10,
    "O3_8H": 1000,
    "O3_1H": 1000,
}

AQI_COLOR = {
    "RGB": {
        1: (0, 228, 0),  # 绿色
        2: (255, 255, 0),  # 黄色
        3: (255, 126, 0),  # 橙色
        4: (255, 0, 0),  # 红色
        5: (143, 63, 151),  # 紫色
        6: (126, 0, 35),  # 褐红色
    },
    "CMYK": {
        1: (40, 0, 100, 0),  # 绿色
        2: (0, 0, 100, 0),  # 黄色
        3: (0, 52, 100, 0),  # 橙色
        4: (0, 100, 100, 0),  # 红色
        5: (5, 58, 0, 41),  # 紫色
        6: (30, 100, 100, 30),  # 褐红色
    },
    "RGB_HEX": {
        1: "#00E400",  # 绿色
        2: "#FFFF00",  # 黄色
        3: "#FF7E00",  # 橙色
        4: "#FF0000",  # 红色
        5: "#8F3F97",  # 紫色
        6: "#7E0023",  # 褐红色
    },
    "CMYK_HEX": {
        1: "#99FF00",  # 绿色
        2: "#FFFF00",  # 黄色
        3: "#FF7A00",  # 橙色
        4: "#FF0000",  # 红色
        5: "#8F3F96",  # 紫色
        6: "#7D0000",  # 褐红色
    },
}
